@@ -35,9 +35,3 @@ class RequestError(SimplipyError):
     """An error related to invalid requests."""
 
     pass
-
-
-class WebsocketError(SimplipyError):
-    """An error related to generic websocket errors."""
-
-    pass
